@@ -13,6 +13,7 @@ import logging
 import sys
 import os
 import glob
+import asyncio
 from textwrap import fill, dedent
 from ipython_genutils.text import indent
 
@@ -285,6 +286,10 @@ class NbConvertApp(JupyterApp):
     @catch_config_error
     def initialize(self, argv=None):
         """Initialize application, notebooks, writer, and postprocessor"""
+        # See https://bugs.python.org/issue37373 :(
+        if sys.version_info[0] == 3 and sys.version_info[1] >= 8 and sys.platform.startswith('win'):
+            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+
         self.init_syspath()
         super().initialize(argv)
         self.init_notebooks()
